@@ -9,6 +9,7 @@
 #' @templateVar pdfpmfeq \deqn{f(x) = \alpha\beta exp(x\beta)exp(\alpha)exp(-exp(x\beta)\alpha)}
 #' @templateVar paramsupport \eqn{\alpha, \beta > 0}
 #' @templateVar distsupport the Non-Negative Reals
+#' @templateVar default shape = 1, scale = 1
 #'
 #' @template class_distribution
 #' @template method_mode
@@ -40,11 +41,7 @@ Gompertz <- R6Class("Gompertz",
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(shape = 1, scale = 1, decorators = NULL) {
-
-      private$.parameters <- getParameterSet(self, shape, scale)
-      suppressMessages(self$setParameterValue(shape = shape, scale = scale))
-
+    initialize = function(shape = NULL, scale = NULL, decorators = NULL) {
       super$initialize(
         decorators = decorators,
         support = PosReals$new(zero = T),
