@@ -37,7 +37,8 @@ autotest_sdistribution <- function(sdist, pars, traits, support, symmetry,
   )
 
   if (!is.null(sdist$public_methods$setParameterValue)) {
-    expect_equal(names(formals(sdist$public_methods$setParameterValue)), c("...", "lst", "error"))
+    expect_equal(names(formals(sdist$public_methods$setParameterValue)),
+                 c("...", "lst", "error", "resolveConflicts"))
   }
   expect_true("decorators" %in% names(formals(sdist$public_methods$initialize)))
   if (!is.null(sdist$public_methods$mean))
@@ -52,10 +53,10 @@ autotest_sdistribution <- function(sdist, pars, traits, support, symmetry,
     expect_equal(names(formals(sdist$public_methods$skewness)), "...")
   if (!is.null(sdist$public_methods$kurtosis))
     expect_equal(formals(sdist$public_methods$kurtosis),
-                 as.pairlist(c(pairlist(excess = TRUE), alist(... = ))))
+                 as.pairlist(c(pairlist(excess = TRUE), alist(... = )))) # nolint
   if (!is.null(sdist$public_methods$entropy))
     expect_equal(formals(sdist$public_methods$entropy),
-                 as.pairlist(c(pairlist(base = 2), alist(... = ))))
+                 as.pairlist(c(pairlist(base = 2), alist(... = )))) # nolint
   if (!is.null(sdist$public_methods$mgf))
     expect_equal(names(formals(sdist$public_methods$mgf)), c("t", "..."))
   if (!is.null(sdist$public_methods$cf))
@@ -465,9 +466,9 @@ expect_equal_distribution <- function(d1, d2) {
   expect_equal(d1$description, d2$description)
   expect_equal(d1$pdf(1:5), d2$pdf(1:5))
   expect_equal(d1$cdf(1:5), d2$cdf(1:5))
-  q = try(d1$quantile(0.1), silent = TRUE)
+  q <- try(d1$quantile(0.1), silent = TRUE)
   if (class(q)[1] != "try-error")
-    expect_equal(d1$quantile(c(0.1,0.2,0.3)), d2$pdf(c(0.1,0.2,0.3)))
+    expect_equal(d1$quantile(c(0.1, 0.2, 0.3)), d2$pdf(c(0.1, 0.2, 0.3)))
 
   p1 <- as.data.table(d1$parameters())
   p1$support <- rsapply(p1$support, "strprint")
