@@ -1,8 +1,9 @@
 test_that("rep custom", {
-  dist = Distribution$new(pdf = function(x) 1/10, name = "Test", type = Set$new(0:10, class = "integer"))
-  rep_dist = rep(dist, 3)
+  dist <- Distribution$new(pdf = function(x) 1 / 10, name = "Test",
+                          type = Set$new(0:10, class = "integer"))
+  rep_dist <- rep(dist, 3)
   expect_equal(getR6Class(rep_dist), "VectorDistribution")
-  expect_equal(rep_dist$pdf(1), data.table(Test1=0.1,Test2=0.1,Test3=0.1))
+  expect_equal(rep_dist$pdf(1), data.table(Test1 = 0.1, Test2 = 0.1, Test3 = 0.1))
 })
 
 test_that("rep dist/param", {
