@@ -35,19 +35,10 @@ test_that("setting", {
 })
 
 test_that("manual", {
-  expect_warning(WeightedDiscrete$new(data = data.frame(x = 1, pdf = 1)), "deprecated")
-  w <- WeightedDiscrete$new(x = 1:5, pdf = dnorm(1:5))
-  expect_equal(w$mgf(1:3), c(w$mgf(1), w$mgf(2), w$mgf(3)))
-  expect_equal(w$cf(1:3), c(w$cf(1), w$cf(2), w$cf(3)))
-  expect_equal(w$pgf(1:3), c(w$pgf(1), w$pgf(2), w$pgf(3)))
-  expect_equal(w$cdf(6), 1)
-  expect_equal(w$cdf(6, lower.tail = FALSE, log.p = TRUE), -Inf)
-  expect_equal(w$cdf(0), 0)
   v <- VectorDistribution$new(distribution = "Weigh", params = data.frame(x = 1:2, pdf = 1))
   expect_error(v$mode(), "cannot be")
   expect_equal(v$mode(100), c(WeightDisc1 = 1, WeightDisc2 = 2))
   expect_equal(v$cdf(3), data.table(WeightDisc1 = 1, WeightDisc2 = 1))
   expect_equal(v$cdf(3, lower.tail = FALSE, log.p = TRUE),
                data.table(WeightDisc1 = -Inf, WeightDisc2 = -Inf))
-  expect_output(w$print(), "WeightDisc()")
 })
